@@ -41,7 +41,11 @@
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtkvbox.h>
 
+#ifdef HAVE_GST10
+#include <gst/interfaces/mixer.h>
+#else
 #include <gst/mixer/mixer.h>
+#endif
 
 #include "applet.h"
 #include "preferences.h"
@@ -345,7 +349,7 @@ cb_dev_selected (GtkComboBox *box,
 		 gpointer    data)
 {
   GnomeVolumeAppletPreferences *prefs = data;
-  GnomeVolumeApplet *applet = (GnomeVolumeApplet *) prefs->applet;
+  /* GnomeVolumeApplet *applet = (GnomeVolumeApplet *) prefs->applet; */
   GtkTreeIter iter;
   const gchar *label;
 
@@ -421,7 +425,6 @@ cb_track_select (GtkTreeSelection *selection,
     for (lst = gtk_tree_selection_get_selected_rows (sel, &model); lst != NULL; lst = lst->next) {
       GstMixerTrack *curr = NULL;
       gchar *it_label;
-      int *volumes;
 
       gtk_tree_model_get_iter (model, &iter, lst->data);
       gtk_tree_model_get (model, &iter, COL_LABEL, &it_label, COL_TRACK, &curr, -1);
