@@ -61,9 +61,10 @@ set_icon_geometry  (GdkWindow *window,
                        (guchar *)&data, 4);
 }
 
-/* Create a new (empty) Sticky Note */
+/* Create a new (empty) Sticky Note at a specific position 
+   and with specific size */
 StickyNote *
-stickynote_new (GdkScreen *screen)
+stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 {
 	StickyNote *note;
 	GladeXML *window;
@@ -133,20 +134,31 @@ stickynote_new (GdkScreen *screen)
 	note->font_color = NULL;
 	note->font = NULL;
 	note->locked = FALSE;
-	note->x = -1;
-	note->y = -1;
-	note->w = 0;
-	note->h = 0;
+	note->x = x;
+	note->y = y;
+	note->w = w;
+	note->h = h;
 
 	/* Customize the window */
 	if (gconf_client_get_bool(stickynotes->gconf,
 				GCONF_PATH "/settings/sticky", NULL))
 		gtk_window_stick(GTK_WINDOW(note->w_window));
-	gtk_window_resize(GTK_WINDOW(note->w_window),
-			gconf_client_get_int(stickynotes->gconf,
-				GCONF_PATH "/defaults/width", NULL),
-			gconf_client_get_int(stickynotes->gconf,
-				GCONF_PATH "/defaults/height", NULL));
+
+	if (w == 0 || h == 0)
+		gtk_window_resize (GTK_WINDOW(note->w_window),
+				gconf_client_get_int(stickynotes->gconf,
+					GCONF_PATH "/defaults/width", NULL),
+				gconf_client_get_int(stickynotes->gconf,
+					GCONF_PATH "/defaults/height", NULL));
+	else
+		gtk_window_resize (GTK_WINDOW(note->w_window),
+				note->w,
+				note->h);
+
+	if (x != -1 && y != -1)
+		gtk_window_move (GTK_WINDOW(note->w_window),
+				note->x,
+				note->y);
 
 	/* Set the button images */
 	size = gtk_icon_size_from_name ("stickynotes_icon_size");
@@ -241,6 +253,13 @@ stickynote_new (GdkScreen *screen)
 	return note;
 }
 
+/* Create a new (empty) Sticky Note */
+StickyNote *
+stickynote_new (GdkScreen *screen)
+{
+	return stickynote_new_aux (screen, -1, -1, 0, 0);
+}
+
 /* Destroy a Sticky Note */
 void stickynote_free(StickyNote *note)
 {
@@ -257,17 +276,48 @@ void stickynote_free(StickyNote *note)
 /* Change the sticky note title and color */
 void stickynote_change_properties (StickyNote *note)
 {
+	GdkColor color;
+	GdkColor font_color;
+	char *color_str = NULL;
+
 	gtk_entry_set_text(GTK_ENTRY(note->w_entry),
 			gtk_label_get_text (GTK_LABEL (note->w_title)));
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(note->w_def_color),
 			note->color == NULL);
-	
-	if (note->color) {
-		GdkColor color;
-		gdk_color_parse(note->color, &color);
+
+	if (note->color)
+		color_str = g_strdup (note->color);
+	else
+	{
+		color_str = gconf_client_get_string (
+			            stickynotes->gconf,
+				    GCONF_PATH "/defaults/color", NULL);
+	}
+
+	if (color_str)
+	{
+		gdk_color_parse (color_str, &color);
+		g_free (color_str);
 		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_color),
-				&color);
+				    &color);
+	}
+
+	if (note->font_color)
+		color_str = g_strdup (note->font_color);
+	else
+	{
+		color_str = gconf_client_get_string (
+			            stickynotes->gconf,
+				    GCONF_PATH "/defaults/font_color", NULL);
+	}
+
+	if (color_str)
+	{
+		gdk_color_parse (color_str, &font_color);
+		g_free (color_str);
+		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_font_color),
+				    &font_color);
 	}
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(note->w_def_font),
@@ -301,15 +351,17 @@ void stickynote_set_title(StickyNote *note, const gchar *title)
 {
 	/* If title is NULL, use the current date as the title. */
 	if (!title) {
-		gchar *date_title;
+		gchar *date_title, *tmp;
 		gchar *date_format = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/settings/date_format", NULL);
 		if (!date_format)
 			date_format = g_strdup ("%x");
-		date_title = get_current_date(date_format);
+		tmp = get_current_date (date_format);
+		date_title = g_locale_to_utf8 (tmp, -1, NULL, NULL, NULL);
 
 		gtk_window_set_title(GTK_WINDOW(note->w_window), date_title);
 		gtk_label_set_text(GTK_LABEL (note->w_title), date_title);
 
+		g_free (tmp);
 		g_free(date_title);
 		g_free(date_format);
 	}
@@ -508,7 +560,7 @@ stickynote_set_font (StickyNote *note, const gchar *font_str, gboolean save)
 		font_str_actual = g_strdup (font_str);
 
 	/* Do not use custom fonts if "use_system_font" is enabled */
-	g_free(rc_style->font_desc);
+	pango_font_description_free (rc_style->font_desc);
 	rc_style->font_desc = font_str_actual ?
 		pango_font_description_from_string (font_str_actual): NULL;
 
@@ -696,7 +748,7 @@ stickynotes_save (void)
 		else
 			note->workspace = 0;
 		
-		/* Retreive the title of the note */
+		/* Retrieve the title of the note */
 		title = gtk_label_get_text(GTK_LABEL(note->w_title));
 
 		/* Retrieve body contents of the note */
@@ -765,6 +817,7 @@ stickynotes_load (GdkScreen *screen)
 	/* WnckScreen *wnck_screen; */
 	GList *new_notes, *tmp1;  /* Lists of StickyNote*'s */
 	GList *new_nodes; /* Lists of xmlNodePtr's */
+	int x, y, w, h;
 	/* The XML file is $HOME/.gnome2/stickynotes_applet, most probably */
 	{
 		gchar *file = g_strdup_printf("%s%s", g_get_home_dir(),
@@ -797,8 +850,49 @@ stickynotes_load (GdkScreen *screen)
 	while (node) {
 		if (!xmlStrcmp(node->name, (const xmlChar *) "note"))
 		{
+			StickyNote *note;
+
+			/* Retrieve and set the window size of the note */
+			{
+				gchar *w_str = (gchar *)xmlGetProp (node, XML_CHAR ("w"));
+				gchar *h_str = (gchar *)xmlGetProp (node, XML_CHAR ("h"));
+				if (w_str && h_str)
+				{
+					w = atoi (w_str);
+					h = atoi (h_str);
+				}
+				else
+				{
+					w = 0;
+					h = 0;
+				}
+
+				g_free (w_str);
+				g_free (h_str);
+			}
+			
+			/* Retrieve and set the window position of the note */
+			{
+				gchar *x_str = (gchar *)xmlGetProp (node, XML_CHAR ("x"));
+				gchar *y_str = (gchar *)xmlGetProp (node, XML_CHAR ("y"));
+
+				if (x_str && y_str)
+				{
+					x = atoi (x_str);
+					y = atoi (y_str);
+				}
+				else
+				{
+					x = -1;
+					y = -1;
+				}
+
+				g_free (x_str);
+				g_free (y_str);
+			}
+
 			/* Create a new note */
-			StickyNote *note = stickynote_new (screen);
+			note = stickynote_new_aux (screen, x, y, w, h);
 			stickynotes->notes = g_list_append (stickynotes->notes,
 					note);
 			new_notes = g_list_append (new_notes, note);
@@ -838,44 +932,6 @@ stickynotes_load (GdkScreen *screen)
 				g_free(font_str);
 			}
 
-			/* Retrieve and set the window size of the note */
-			{
-				gchar *w_str = (gchar *)xmlGetProp(node, XML_CHAR ("w"));
-				gchar *h_str = (gchar *)xmlGetProp(node, XML_CHAR ("h"));
-				if (w_str && h_str)
-					gtk_window_resize (GTK_WINDOW (
-							note->w_window),
-							atoi(w_str),
-							atoi(h_str));
-				gtk_window_get_size (GTK_WINDOW (
-							note->w_window),
-						&note->w, &note->h);
-				g_free(w_str);
-				g_free(h_str);
-			}
-			
-			/* Retrieve and set the window position of the note */
-			{
-				gchar *x_str = (gchar *)xmlGetProp(node, XML_CHAR ("x"));
-				gchar *y_str = (gchar *)xmlGetProp(node, XML_CHAR ("y"));
-				if (x_str && y_str)
-				{
-					if (atoi(x_str) != -1 ||
-							atoi(y_str) !=-1)
-					{
-					    gtk_window_move (GTK_WINDOW (
-							note->w_window),
-							    atoi(x_str),
-							    atoi(y_str));
-					}
-					gtk_window_get_position (GTK_WINDOW (
-							note->w_window),
-							&note->x, &note->y);
-					g_free(x_str);
-					g_free(y_str);
-				}
-			}
-			
 			/* Retrieve the workspace */
 			{
 				char *workspace_str;
